.. currentmodule:: cratermaker

.. _ug-surface:

.. image:: ../_static/surface_grid.png
    :alt: Surface
    :align: center
    :width: 300px


Surface
=======

The Surface object is used to represent target body's topography and other properties of its surface.